# From SpaceX web page:
takeoff_weight = 541300.0      # kg
stage1_burn_time = 162         # s
stage1_thrust_sl = 6806000.0   # N (kg m / s^2)
stage1_thrust_vac = 7426000.0  # N (kg m / s^2)

# From a blog that I can't find again...
stage1_fuel = 385500.0        # kg

gravity = 9.81  # m / s^2


def thrust(current_altitude, thrust_at_sea_level, thrust_in_vacuum):
    """
    Calculate thrust as a function of altitude, using the given
    values for thrust at sea level and in vacuum. We assume a linear
    interpolation, and that vacuum begins at 120km (100-120km seems
    a reasonable guess; see
    https://en.wikipedia.org/wiki/Atmosphere_of_Earth).
    """

    if current_altitude < 120000:
        f = current_altitude / 120000
        return (f * (thrust_in_vacuum - thrust_at_sea_level)) + thrust_at_sea_level
    else:
        return thrust_in_vacuum

# Calculate some starting values
stage1_burn_rate = stage1_fuel / stage1_burn_time  # kg / s
non_fuel_weight = takeoff_weight - stage1_fuel

# Initialise some variables we are going to need in the simulation
altitude = 0
velocity = 0
time = 0
delta_t = 1

# Run the loop until the rocket runs out of fuel
while stage1_fuel > 0.5 * stage1_burn_rate:

    mass = non_fuel_weight + stage1_fuel
    stage1_fuel = stage1_fuel - (stage1_burn_rate * delta_t)
    acceleration = thrust(altitude, stage1_thrust_sl, stage1_thrust_vac) / mass - gravity

    velocity = velocity + acceleration * delta_t
    altitude = altitude + velocity * delta_t
    time = time + delta_t

    # Print out some information so we can track the progress of the rocket
    print("Time: {}, Velocity: {:.2f}, Altitude: {:.2f}".format(time, velocity, altitude))

